#include <QApplication>
#include <QTextCodec>
#include <QImage>
#include <QFontDatabase>
#include <QStringList>
#include <QPainter>

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QTextCodec *sjis = QTextCodec::codecForName("Shift-JIS");
    QTextCodec *jis = QTextCodec::codecForName("ISO-2022-JP");

    int id = QFontDatabase::addApplicationFont(":/mplus-1mn-regular.ttf");
    QString family = QFontDatabase::applicationFontFamilies(id).at(0);
    QFont font(family);
    font.setPointSizeF(9);
    font.setStyleHint(QFont::AnyStyle,
                      QFont::StyleStrategy(QFont::PreferBitmap | QFont::NoAntialias));

    // フォント描画
    const int size = 6;
    // 半角
    char hbuf[2] = { 0x00, 0x00 };
    const int hShift = 3;   //余白調整のため描画を上にずらす
    QImage hImage(1152, 24, QImage::Format_RGB32);
    hImage.fill(0);
    QPainter hPainter(&hImage);
    hPainter.setPen(Qt::white);
    hPainter.setFont(font);
    for( int y=0; y<2; y++ ){
        for( int x=32; x<128; x++ ){
            hbuf[0] = x + y * 128;
            QString letter(sjis->toUnicode(hbuf));
            hPainter.drawText(QRect(x*size, y*size*2-hShift, size, size*2+hShift), Qt::AlignLeft, letter);
        }
    }
    hImage.convertToFormat(QImage::Format_Indexed8).save("fonth12.png");


    // 全角
    char zbuf[6] = { 0x1B, 0x24, 0x42, 0x00, 0x00, 0x00 };  //前半3バイトは漢字を使うための制御コード
    const int zShift = 2;   //余白調整のため描画を上にずらす
    QImage zImage(1152, 1152, QImage::Format_RGB32);
    zImage.fill(0);
    QPainter zPainter(&zImage);
    zPainter.setPen(Qt::white);
    font.setPointSizeF(9);
    zPainter.setFont(font);
    for( int y=1; y<95; y++ ){
        for( int x=1; x<95; x++ ){
            zbuf[3] = y + 0x20;
            zbuf[4] = x + 0x20;
            QTextCodec::ConverterState state(QTextCodec::ConvertInvalidToNull);
            QString letter(jis->toUnicode(zbuf));
            zPainter.drawText(QRect(x*size*2, y*size*2-zShift, size*2+1, size*2+zShift), Qt::AlignLeft, letter);
        }
    }
    zImage.convertToFormat(QImage::Format_Indexed8).save("fontz12.png");

    return 0;
}
